0.9.9 API documentation: round.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
round.hpp File Reference

GLM_GTC_round More...

Go to the source code of this file.

## Functions
template<typename genType >
GLM_FUNC_DECL genType | ceilMultiple (genType v, genType Multiple)
| Higher multiple number of Source. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | ceilMultiple (vec< L, T, Q > const &v, vec< L, T, Q > const &Multiple)
| Higher multiple number of Source. More...
template<typename genIUType >
GLM_FUNC_DECL genIUType | ceilPowerOfTwo (genIUType v)
| Return the power of two number which value is just higher the input value, round up to a power of two. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | ceilPowerOfTwo (vec< L, T, Q > const &v)
| Return the power of two number which value is just higher the input value, round up to a power of two. More...
template<typename genType >
GLM_FUNC_DECL genType | floorMultiple (genType v, genType Multiple)
| Lower multiple number of Source. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | floorMultiple (vec< L, T, Q > const &v, vec< L, T, Q > const &Multiple)
| Lower multiple number of Source. More...
template<typename genIUType >
GLM_FUNC_DECL genIUType | floorPowerOfTwo (genIUType v)
| Return the power of two number which value is just lower the input value, round down to a power of two. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | floorPowerOfTwo (vec< L, T, Q > const &v)
| Return the power of two number which value is just lower the input value, round down to a power of two. More...
template<typename genType >
GLM_FUNC_DECL genType | roundMultiple (genType v, genType Multiple)
| Lower multiple number of Source. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | roundMultiple (vec< L, T, Q > const &v, vec< L, T, Q > const &Multiple)
| Lower multiple number of Source. More...
template<typename genIUType >
GLM_FUNC_DECL genIUType | roundPowerOfTwo (genIUType v)
| Return the power of two number which value is the closet to the input value. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | roundPowerOfTwo (vec< L, T, Q > const &v)
| Return the power of two number which value is the closet to the input value. More...

## Detailed Description

GLM_GTC_round

See also
  Core features (dependence)
  GLM_GTC_round (dependence)

Definition in file round.hpp.